#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import print_function
from __future__ import absolute_import

__author__     = "Lluís Vilanova"
__copyright__  = "Copyright 2008-2019, Lluís Vilanova"
__license__    = "GPL version 3 or later"


__version_info__ = (2, 0, 3)
__version__ = ".".join([str(i) for i in __version_info__])
